@@ -6,12 +6,22 @@ sub uptime {
         or die "Failed to open /proc/uptime: $!";
 
     my $line = <$proc_uptime>;
-    my $uptime;
-    if ($class->want_hires()) {
-        ($uptime) = $line =~ /^(\d+(\.\d+)?)/;
-    } else {
-        ($uptime) = $line =~ /^(\d+)/;
+    my ($uptime) = $line =~ /^(\d+)/;
+    return $uptime;
+}
+
+sub uptime_hires {
+    my $class = shift;
+
+    unless ($class->want_hires()) {
+        die "uptime_hires: you need to import Unix::Uptime with ':hires'";
     }
+
+    open my $proc_uptime, '<', '/proc/uptime'
+        or die "Failed to open /proc/uptime: $!";
+
+    my $line = <$proc_uptime>;
+    my ($uptime) = $line =~ /^(\d+(\.\d+)?)/;
     return $uptime;
 }
 
